#
# spec file for package cuneiform
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define major   1
Name:           cuneiform
Version:        1.1.0
Release:        bp155.2.12
Summary:        OCR System
License:        BSD-3-Clause
Group:          Productivity/Graphics/Other
URL:            http://launchpad.net/cuneiform-linux
Source0:        http://launchpad.net/cuneiform-linux/1.1/1.1/+download/%{name}-linux-%{version}.tar.bz2
Source1:        cuneiform.1
Patch0:         cuneiform-1.1.0-c-assert.patch
Patch1:         cuneiform-1.1.0-fix_buffer_overflow.patch
Patch2:         cuneiform-1.1.0-fix_buffer_overflow_2.patch
Patch3:         cuneiform-1.1.0-gcc6.patch
Patch4:         cuneiform-1.1.0-gcc7.patch
Patch6:         cuneiform-1.1.0-libm.patch
Patch7:         cuneiform-1.1.0-strings.patch
Patch8:         cuneiform-1.1.0-typos.patch
Patch9:         cuneiform-brp.patch
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  libMagick++-devel
Conflicts:      cuneiform-multilang
Provides:       ocr-engine
ExclusiveArch:  %{ix86} x86_64

%description
Cuneiform is an multi-language OCR system originally developed and open
sourced by Cognitive Technologies. Cuneiform was originally a Windows
program, which was ported to Linux by Jussi Pakkanen.
Supported languages: eng ger fra rus swe spa ita ruseng ukr srp hrv pol
dan por dut cze rum hun bul slo lav lit est tur.

%package -n lib%{name}%{major}
Summary:        Cuneiform Shared Libraries
Group:          System/Libraries

%description -n lib%{name}%{major}
Shared libraries for the package cuneiform.

%package -n lib%{name}-devel
Summary:        Development Files for Cuneiform
Group:          Development/Libraries/C and C++
Requires:       libcuneiform%{major} = %{version}

%description -n lib%{name}-devel
Development files for the package cuneiform.

%prep
%setup -q -n %{name}-linux-%{version}
%autopatch -p1

%build
# https://gcc.gnu.org/bugzilla/show_bug.cgi?id=85788
export CXXFLAGS="%{optflags} -Wno-stringop-overflow"
export CFLAGS="%{optflags} -Wno-stringop-overflow"
%cmake \
    -DBUILD_TESTING=ON
%make_jobs

%install
%cmake_install
install -Dpm 0644 %{SOURCE1} \
  %{buildroot}%{_mandir}/man1/%{name}.1
%fdupes %{buildroot}%{_datadir}

%check
export LD_LIBRARY_PATH=%{buildroot}%{_libdir}${LD_LIBRARY_PATH:+:${LD_LIBRARY_PATH}}
%ctest

%post -n lib%{name}%{major} -p /sbin/ldconfig
%postun -n lib%{name}%{major} -p /sbin/ldconfig

%files
%doc readme.txt issues.txt cuneiform_src/Kern/license.txt
%{_datadir}/%{name}
%{_bindir}/%{name}
%{_mandir}/man?/*

%files -n lib%{name}%{major}
%{_libdir}/*.so.*

%files -n lib%{name}-devel
%{_libdir}/*.so
%{_includedir}/*.h

%changelog
* Mon Jul 23 2018 guillaume.gardet@opensuse.org
- According to the readme.txt file, it is only working on x86*
* Tue May 15 2018 tchvatal@suse.com
- Disable one errornous warning/error from brp as it is gcc bug
* Mon May 14 2018 tchvatal@suse.com
- Enable tests
* Mon May 14 2018 tchvatal@suse.com
- Add patch cuneiform-brp.patch to fix all the brp fails
* Mon May 14 2018 tchvatal@suse.com
- Drop GM patch as we stick with ImageMagick mostly:
  * cuneiform-1.1.0-graphicsmagick.patch
* Mon May 14 2018 tchvatal@suse.com
- Add patches from other distributions:
  * cuneiform-1.1.0-c-assert.patch
  * cuneiform-1.1.0-fix_buffer_overflow.patch
  * cuneiform-1.1.0-fix_buffer_overflow_2.patch
  * cuneiform-1.1.0-gcc6.patch
  * cuneiform-1.1.0-gcc7.patch
  * cuneiform-1.1.0-graphicsmagick.patch
  * cuneiform-1.1.0-libm.patch
  * cuneiform-1.1.0-strings.patch
  * cuneiform-1.1.0-typos.patch
* Thu Jan  4 2018 mpluskal@suse.com
- Cleanup with spec-cleaner
- Use cmake macros
* Sun Nov  6 2011 lazy.kent@opensuse.org
- Provides ocr-engine (required by yagf and others).
- Corrected License tag.
- man marked as doc.
- spec cleanup.
* Fri Jun  3 2011 lazy.kent@opensuse.org
- provides cuneiform-ocr (required by yagf)
* Tue Apr 19 2011 lazy.kent@opensuse.org
- update to 1.1.0
- dropped 64bit_issue patch
* Mon Jul  5 2010 lazy.kent.suse@gmail.com
- update to 1.0.0
* Thu Feb 25 2010 lazy.kent.suse@gmail.com
- moved man to man1
* Tue Feb 23 2010 lazy.kent.suse@gmail.com
- fixed build with GCC 4.5
- added man page from Debian project
* Sun Feb  7 2010 lazy.kent.suse@gmail.com
- update to 0.9.0
- splitted shared libraries and development files
- removed obsolete libdir patch
* Fri Jan 22 2010 lazy.kent.suse@gmail.com
- shared libraries moved to a subdirectory
- gccwarnings.patch renamed according to the real patch version
* Fri Oct  2 2009 lazy.kent.suse@gmail.com
- added supported languages to description
- corrected date in changelog section
* Tue Sep 29 2009 lazy.kent.suse@gmail.com
- corrected BuildRequires: cmake >= 2.6.2
* Mon Sep 28 2009 lazy.kent.suse@gmail.com
- update to 0.8.0
- spec-file corrected
- added license.txt to docs
* Sun Feb  1 2009 lazy.kent.suse@gmail.com
- initial package created
